Class: Rudder::Analytics::Request

Inherits:
Object
  • Object
show all
Includes:
Defaults::Request, Logging, Utils
Defined in:
lib/rudder/analytics/request.rb

Constant Summary

Constants included from Utils

Utils::UTC_OFFSET_WITHOUT_COLON, Utils::UTC_OFFSET_WITH_COLON

Constants included from Defaults::Request

Defaults::Request::DATA_PLANE_URL, Defaults::Request::HEADERS, Defaults::Request::HOST, Defaults::Request::PATH, Defaults::Request::PORT, Defaults::Request::RETRIES, Defaults::Request::SSL

Class Attribute Summary collapse

Instance Method Summary collapse

Methods included from Logging

included, #logger

Methods included from Utils

#date_in_iso8601, #datetime_in_iso8601, #formatted_offset, #isoify_dates, #isoify_dates!, #seconds_to_utc_offset, #stringify_keys, #symbolize_keys, #symbolize_keys!, #time_in_iso8601, #uid

Constructor Details

#initialize(options = {}) ⇒ Request

public: Creates a new request object to send analytics batch



22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/rudder/analytics/request.rb', line 22

def initialize(options = {})
  options[:host] ||= HOST
  options[:port] ||= PORT
  options[:ssl] ||= SSL
  @headers = options[:headers] || HEADERS
  @path = options[:path] || PATH
  @retries = options[:retries] || RETRIES
  @backoff_policy =
    options[:backoff_policy] || Rudder::Analytics::BackoffPolicy.new

  uri = URI(options[:data_plane_url] || DATA_PLANE_URL)
  printf("************\n")
  printf("************\n")
  printf(options[:data_plane_url] || DATA_PLANE_URL)
  printf("\n************\n")
  printf(uri.host)
  printf("\n************\n")
  printf(uri.port.to_s)
  printf("************\n")

  http = Net::HTTP.new(uri.host, uri.port)
  http.use_ssl = options[:ssl]
  http.read_timeout = 8
  http.open_timeout = 4

  @http = http
end

Class Attribute Details

.stubObject



145
146
147
# File 'lib/rudder/analytics/request.rb', line 145

def stub
  @stub || ENV['STUB']
end

Instance Method Details

#post(write_key, batch) ⇒ Object

public: Posts the write key and batch of messages to the API.

returns - Response of the status and error if it exists



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/rudder/analytics/request.rb', line 53

def post(write_key, batch)
  logger.debug("Sending request for #{batch.length} items")

  last_response, exception = retry_with_backoff(@retries) do
    status_code, body = send_request(write_key, batch)
    
    error = JSON.parse(body)['error'] rescue error = JSON.parse(body.to_json)['error']  # rudder server now return 'OK'

    should_retry = should_retry_request?(status_code, body)
    logger.debug("Response status code: #{status_code}")
    logger.debug("Response error: #{error}") if error

    [Response.new(status_code, error), should_retry]
  end

  if exception
    logger.error(exception.message)
    exception.backtrace.each { |line| logger.error(line) }
    Response.new(-1, exception.to_s)
  else
    last_response
  end
end